class RcChannels:
    def __init__(self, message=None):
        if message is None:
            self.all = message
            self.time_boot_ms = None
            self.chancount = None
            self.chan1_raw = None
            self.chan2_raw = None
            self.chan3_raw = None
            self.chan4_raw = None
            self.chan5_raw = None
            self.chan6_raw = None
            self.chan7_raw = None
            self.chan8_raw = None
            self.chan9_raw = None
            self.chan10_raw = None
            self.chan11_raw = None
            self.chan12_raw = None
            self.chan13_raw = None
            self.chan14_raw = None
            self.chan15_raw = None
            self.chan16_raw = None
            self.chan17_raw = None
            self.chan18_raw = None
            self.rssi = None
        else:
            self.all = message
            self.time_boot_ms = message.time_boot_ms
            self.chancount = message.chancount
            self.chan1_raw = message.chan1_raw
            self.chan2_raw = message.chan2_raw
            self.chan3_raw = message.chan3_raw
            self.chan4_raw = message.chan4_raw
            self.chan5_raw = message.chan5_raw
            self.chan6_raw = message.chan6_raw
            self.chan7_raw = message.chan7_raw
            self.chan8_raw = message.chan8_raw
            self.chan9_raw = message.chan9_raw
            self.chan10_raw = message.chan10_raw
            self.chan11_raw = message.chan11_raw
            self.chan12_raw = message.chan12_raw
            self.chan13_raw = message.chan13_raw
            self.chan14_raw = message.chan14_raw
            self.chan15_raw = message.chan15_raw
            self.chan16_raw = message.chan16_raw
            self.chan17_raw = message.chan17_raw
            self.chan18_raw = message.chan18_raw
            self.rssi = message.rssi
